# appscii

## Applications in ASCII for Python

Appscii is a lightweight Python toolkit for creating cross-platform applications with a purely text-based interface meant to run in a terminal or console.

## Installation

The appscii library is easy to install using pip:
```
pip install appscii
```

## Usage

There is a demonstration application you can see by running the `appscii` command:
```
appscii
```

## Alternatives

- Python Prompt Toolkit
- Textualize
- DeskApp

## Author

Created by Shawn A. Wilson [lannocc@yahoo.com] aka LANNOCC.

